@@ -1,7 +1,8 @@
 use warnings;
 use strict;
+use feature ':5.14';
 
-package Text::Parser 0.915;
+package Text::Parser 0.916;
 
 # ABSTRACT: Simplifies text parsing. Easily extensible to parse any text format.
 
@@ -14,9 +15,6 @@ use Moose;
 use MooseX::CoverableModifiers;
 use MooseX::StrictConstructor;
 use namespace::autoclean;
-use FileHandle;
-use Syntax::Keyword::Try;
-use feature ':5.14';
 use Moose::Util 'apply_all_roles', 'ensure_all_roles';
 use Moose::Util::TypeConstraints;
 use String::Util qw(trim ltrim rtrim);
@@ -26,6 +24,8 @@ enum 'Text::Parser::Types::MultilineType' => [qw(join_next join_last)];
 enum 'Text::Parser::Types::TrimType'      => [qw(l r b n)];
 
 no Moose::Util::TypeConstraints;
+use FileHandle;
+use Try::Tiny;
 
 
 sub BUILD {
@@ -142,7 +142,7 @@ sub __parse_line {
 sub __try_to_parse {
     my ( $self, $line ) = @_;
     try { $self->save_record($line); }
-    finally { }
+    catch { die $_; };
 }
 
 
@@ -309,7 +309,7 @@ Text::Parser - Simplifies text parsing. Easily extensible to parse any text form
 
 =head1 VERSION
 
-version 0.915
+version 0.916
 
 =head1 SYNOPSIS
 
@@ -734,11 +734,9 @@ The above program reads the content of a given CSV file and prints the content o
 
 =head2 Example 2 : Error checking
 
-This class encourages the use of exceptions for error checking. Read the documentation for C<L<Exceptions>> to learn about creating, throwing, and catching exceptions in Perl. This class uses exceptions based on L<Throwable::SugarFactory>, but you could use any of the other classes listed in L<Exceptions>. We recommend C<use>ing L<Keyword::Syntax::Try> to catch exceptions, but you may C<use> the other alternatives described in L<Exceptions>.
+This class encourages the use of exceptions for error checking. Read the documentation for C<L<Exceptions>> to learn about creating, throwing, and catching exceptions in Perl 5. All of the methods of creating, throwing, and catching exceptions described in L<Exceptions> are supported.
 
-=head3 Detecting syntax errors
-
-You I<can> throw exceptions from C<save_record> when you detect a syntax error. This class will C<close> all filehandles automatically as soon as an exception is thrown from C<save_record>. The exception will pass through to C<::main> unless you intercept it in your derived class. To allow all exceptions to pass through, we use the L<Syntax::Keyword::Try> which implements the C<try-catch> as I would expect it. An earlier implementation of this class used L<Try::Tiny> and exceptions would not properly pass through.
+You I<can> throw exceptions from C<save_record>, for example, when you detect a syntax error. The C<read> method will C<close> all filehandles automatically as soon as an exception is thrown. The exception will pass through to C<::main> unless you catch and handle it in your derived class.
 
 Here is an example showing the use of an exception to detect a syntax error in a file:
 
@@ -758,12 +756,6 @@ Here is an example showing the use of an exception to detect a syntax error in a
         $self->SUPER::save_record($line);
     }
 
-=head3 Exceptions thrown by C<Text::Parser>
-
-C<Text::Parser> throws a number of different types of exceptions that are described in L<Text::Parser::Errors>. The base class for all these exceptions is C<Text::Parser::Errors::GenericError>.
-
-You can optionally build a handler using L<Dispatch::Class>, to handle exceptions of various types.
-
 =head2 Example 3 : Aborting without errors
 
 We can also abort parsing a text file without throwing an exception. This could be if we got the information we needed. For example:
@@ -919,6 +911,14 @@ Some text formats allow a line to indicate that it is continuing from a previous
 
 Try this parser with a SPICE deck with continuation characters and see what you get. Try having errors in the file. You may now write a more elaborate method for C<save_record> above and that could be used to parse a full SPICE file.
 
+=head1 ERRORS AND EXCEPTIONS
+
+This class adopts the principle that errors should be indicated with exceptions, and not a special return code or an error code. Several exceptions described in L<Text::Parser::Errors> could be thrown when using C<Text::Parser>. All these are derived from C<Text::Parser::Errors::GenericError>. Since this is a L<Moose> class, exceptions derived from C<L<Moose::Exception>> will be thrown when methods of this class are used improperly.
+
+In addition to these two types of exceptions, the developer can make her own exceptions. L<This example|/"Example 2 : Error checking"> shows how she could create her own exceptions. We recommend L<Syntax::Keyword::Try> (or L<Try::Tiny> if you can't use that) to catch exceptions.
+
+Since the handling of exceptions depends on their type, one could optionally build a handler routine using L<Dispatch::Class>.
+
 =head1 SEE ALSO
 
 =over 4
