@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-package Text::Parser::AutoSplit 0.915;
+package Text::Parser::AutoSplit 0.916;
 
 # ABSTRACT: A role that adds the ability to auto-split a line into fields
 
@@ -52,7 +52,7 @@ Text::Parser::AutoSplit - A role that adds the ability to auto-split a line into
 
 =head1 VERSION
 
-version 0.915
+version 0.916
 
 =head1 SYNOPSIS
 
@@ -71,8 +71,8 @@ version 0.915
 
     sub save_record {
         my $self = shift;
-        return $self->abort_reading if $self->NS > 0 and $self->field(0) eq 'STOP_READING';
-        $self->SUPER::save_record(@_) if $self->NS > 0 and $self->field(0) !~ /^[#]/;
+        return $self->abort_reading if $self->NF > 0 and $self->field(0) eq 'STOP_READING';
+        $self->SUPER::save_record(@_) if $self->NF > 0 and $self->field(0) !~ /^[#]/;
     }
 
     package main;
